var indexSectionsWithContent =
{
  0: "01234acdefgilmnprstv",
  1: "s",
  2: "s",
  3: "cdglmps",
  4: "acfr",
  5: "ms"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Pages"
};

